API reference
======

Submodules
----------

fitter
^^^^^^^

.. automodule:: cdsaxs.fitter
   :members:
   :undoc-members:
   :show-inheritance:

residual
^^^^^^^^

.. automodule:: cdsaxs.residual
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   cdsaxs.simulations